{% if component.as_pdf %}<img width="100" src="data:image/jpeg;base64, {{ component.base64 }}"/>{% else %}
<script type="text/javascript" src="/static/js/jquery.qrcode.min.js"></script>
<div id="{{ component.text|slugify }}"></div>
<script>jQuery('#{{ component.text|slugify }}').qrcode({width: 100, height: 100, text: "{{ component.text }}"});</script>
{% endif %}