{% if component.as_pdf %}{% else %}
{% if component.items %}
    <div class="shortcut-wrapper">
        {% for item in component.items %}
            <a href="{{ item.url }}" class="shortcut-link {{ item.style }}">
                <span class="shortcut-icon">
                    <i class="fa {{ item.icon }}"></i>
                    {% if item.count %}
                        <span class="shortcut-alert">{{ item.count }}</span>
                    {% endif %}
                </span>
                <span class="shortcut-description">{{ item.description }}</span>
            </a>
        {% endfor %}
    </div>
{% endif %}
{% endif %}