# -*- coding: utf-8 -*-

ICONS = list()
ICONS.append('glass')
ICONS.append('music')
ICONS.append('search')
ICONS.append('envelope-o')
ICONS.append('heart')
ICONS.append('star')
ICONS.append('star-o')
ICONS.append('user')
ICONS.append('film')
ICONS.append('th-large')
ICONS.append('th')
ICONS.append('th-list')
ICONS.append('check')
ICONS.append('remove')
ICONS.append('close')
ICONS.append('times')
ICONS.append('search-plus')
ICONS.append('search-minus')
ICONS.append('power-off')
ICONS.append('signal')
ICONS.append('gear')
ICONS.append('cog')
ICONS.append('trash-o')
ICONS.append('home')
ICONS.append('file-o')
ICONS.append('clock-o')
ICONS.append('road')
ICONS.append('download')
ICONS.append('arrow-circle-o-down')
ICONS.append('arrow-circle-o-up')
ICONS.append('inbox')
ICONS.append('play-circle-o')
ICONS.append('rotate-right')
ICONS.append('repeat')
ICONS.append('refresh')
ICONS.append('list-alt')
ICONS.append('lock')
ICONS.append('flag')
ICONS.append('headphones')
ICONS.append('volume-off')
ICONS.append('volume-down')
ICONS.append('volume-up')
ICONS.append('qrcode')
ICONS.append('barcode')
ICONS.append('tag')
ICONS.append('tags')
ICONS.append('book')
ICONS.append('bookmark')
ICONS.append('print')
ICONS.append('camera')
ICONS.append('font')
ICONS.append('bold')
ICONS.append('italic')
ICONS.append('text-height')
ICONS.append('text-width')
ICONS.append('align-left')
ICONS.append('align-center')
ICONS.append('align-right')
ICONS.append('align-justify')
ICONS.append('list')
ICONS.append('dedent')
ICONS.append('outdent')
ICONS.append('indent')
ICONS.append('video-camera')
ICONS.append('photo')
ICONS.append('image')
ICONS.append('picture-o')
ICONS.append('pencil')
ICONS.append('map-marker')
ICONS.append('adjust')
ICONS.append('tint')
ICONS.append('edit')
ICONS.append('pencil-square-o')
ICONS.append('share-square-o')
ICONS.append('check-square-o')
ICONS.append('arrows')
ICONS.append('step-backward')
ICONS.append('fast-backward')
ICONS.append('backward')
ICONS.append('play')
ICONS.append('pause')
ICONS.append('stop')
ICONS.append('forward')
ICONS.append('fast-forward')
ICONS.append('step-forward')
ICONS.append('eject')
ICONS.append('chevron-left')
ICONS.append('chevron-right')
ICONS.append('plus-circle')
ICONS.append('minus-circle')
ICONS.append('times-circle')
ICONS.append('check-circle')
ICONS.append('question-circle')
ICONS.append('info-circle')
ICONS.append('crosshairs')
ICONS.append('times-circle-o')
ICONS.append('check-circle-o')
ICONS.append('ban')
ICONS.append('arrow-left')
ICONS.append('arrow-right')
ICONS.append('arrow-up')
ICONS.append('arrow-down')
ICONS.append('mail-forward')
ICONS.append('share')
ICONS.append('expand')
ICONS.append('compress')
ICONS.append('plus')
ICONS.append('minus')
ICONS.append('asterisk')
ICONS.append('exclamation-circle')
ICONS.append('gift')
ICONS.append('leaf')
ICONS.append('fire')
ICONS.append('eye')
ICONS.append('eye-slash')
ICONS.append('warning')
ICONS.append('exclamation-triangle')
ICONS.append('plane')
ICONS.append('calendar')
ICONS.append('random')
ICONS.append('comment')
ICONS.append('magnet')
ICONS.append('chevron-up')
ICONS.append('chevron-down')
ICONS.append('retweet')
ICONS.append('shopping-cart')
ICONS.append('folder')
ICONS.append('folder-open')
ICONS.append('arrows-v')
ICONS.append('arrows-h')
ICONS.append('bar-chart-o')
ICONS.append('bar-chart')
ICONS.append('twitter-square')
ICONS.append('facebook-square')
ICONS.append('camera-retro')
ICONS.append('key')
ICONS.append('gears')
ICONS.append('cogs')
ICONS.append('comments')
ICONS.append('thumbs-o-up')
ICONS.append('thumbs-o-down')
ICONS.append('star-half')
ICONS.append('heart-o')
ICONS.append('sign-out')
ICONS.append('linkedin-square')
ICONS.append('thumb-tack')
ICONS.append('external-link')
ICONS.append('sign-in')
ICONS.append('trophy')
ICONS.append('github-square')
ICONS.append('upload')
ICONS.append('lemon-o')
ICONS.append('phone')
ICONS.append('square-o')
ICONS.append('bookmark-o')
ICONS.append('phone-square')
ICONS.append('twitter')
ICONS.append('facebook-f')
ICONS.append('facebook')
ICONS.append('github')
ICONS.append('unlock')
ICONS.append('credit-card')
ICONS.append('feed')
ICONS.append('rss')
ICONS.append('hdd-o')
ICONS.append('bullhorn')
ICONS.append('bell')
ICONS.append('certificate')
ICONS.append('hand-o-right')
ICONS.append('hand-o-left')
ICONS.append('hand-o-up')
ICONS.append('hand-o-down')
ICONS.append('arrow-circle-left')
ICONS.append('arrow-circle-right')
ICONS.append('arrow-circle-up')
ICONS.append('arrow-circle-down')
ICONS.append('globe')
ICONS.append('wrench')
ICONS.append('tasks')
ICONS.append('filter')
ICONS.append('briefcase')
ICONS.append('arrows-alt')
ICONS.append('group')
ICONS.append('users')
ICONS.append('chain')
ICONS.append('link')
ICONS.append('cloud')
ICONS.append('flask')
ICONS.append('cut')
ICONS.append('scissors')
ICONS.append('copy')
ICONS.append('files-o')
ICONS.append('paperclip')
ICONS.append('save')
ICONS.append('floppy-o')
ICONS.append('square')
ICONS.append('navicon')
ICONS.append('reorder')
ICONS.append('bars')
ICONS.append('list-ul')
ICONS.append('list-ol')
ICONS.append('strikethrough')
ICONS.append('underline')
ICONS.append('table')
ICONS.append('magic')
ICONS.append('truck')
ICONS.append('pinterest')
ICONS.append('pinterest-square')
ICONS.append('google-plus-square')
ICONS.append('google-plus')
ICONS.append('money')
ICONS.append('caret-down')
ICONS.append('caret-up')
ICONS.append('caret-left')
ICONS.append('caret-right')
ICONS.append('columns')
ICONS.append('unsorted')
ICONS.append('sort')
ICONS.append('sort-down')
ICONS.append('sort-desc')
ICONS.append('sort-up')
ICONS.append('sort-asc')
ICONS.append('envelope')
ICONS.append('linkedin')
ICONS.append('rotate-left')
ICONS.append('undo')
ICONS.append('legal')
ICONS.append('gavel')
ICONS.append('dashboard')
ICONS.append('tachometer')
ICONS.append('comment-o')
ICONS.append('comments-o')
ICONS.append('flash')
ICONS.append('bolt')
ICONS.append('sitemap')
ICONS.append('umbrella')
ICONS.append('paste')
ICONS.append('clipboard')
ICONS.append('lightbulb-o')
ICONS.append('exchange')
ICONS.append('cloud-download')
ICONS.append('cloud-upload')
ICONS.append('user-md')
ICONS.append('stethoscope')
ICONS.append('suitcase')
ICONS.append('bell-o')
ICONS.append('coffee')
ICONS.append('cutlery')
ICONS.append('file-text-o')
ICONS.append('building-o')
ICONS.append('hospital-o')
ICONS.append('ambulance')
ICONS.append('medkit')
ICONS.append('fighter-jet')
ICONS.append('beer')
ICONS.append('h-square')
ICONS.append('plus-square')
ICONS.append('angle-double-left')
ICONS.append('angle-double-right')
ICONS.append('angle-double-up')
ICONS.append('angle-double-down')
ICONS.append('angle-left')
ICONS.append('angle-right')
ICONS.append('angle-up')
ICONS.append('angle-down')
ICONS.append('desktop')
ICONS.append('laptop')
ICONS.append('tablet')
ICONS.append('mobile-phone')
ICONS.append('mobile')
ICONS.append('circle-o')
ICONS.append('quote-left')
ICONS.append('quote-right')
ICONS.append('spinner')
ICONS.append('circle')
ICONS.append('mail-reply')
ICONS.append('reply')
ICONS.append('github-alt')
ICONS.append('folder-o')
ICONS.append('folder-open-o')
ICONS.append('smile-o')
ICONS.append('frown-o')
ICONS.append('meh-o')
ICONS.append('gamepad')
ICONS.append('keyboard-o')
ICONS.append('flag-o')
ICONS.append('flag-checkered')
ICONS.append('terminal')
ICONS.append('code')
ICONS.append('mail-reply-all')
ICONS.append('reply-all')
ICONS.append('star-half-empty')
ICONS.append('star-half-full')
ICONS.append('star-half-o')
ICONS.append('location-arrow')
ICONS.append('crop')
ICONS.append('code-fork')
ICONS.append('unlink')
ICONS.append('chain-broken')
ICONS.append('question')
ICONS.append('info')
ICONS.append('exclamation')
ICONS.append('superscript')
ICONS.append('subscript')
ICONS.append('eraser')
ICONS.append('puzzle-piece')
ICONS.append('microphone')
ICONS.append('microphone-slash')
ICONS.append('shield')
ICONS.append('calendar-o')
ICONS.append('fire-extinguisher')
ICONS.append('rocket')
ICONS.append('maxcdn')
ICONS.append('chevron-circle-left')
ICONS.append('chevron-circle-right')
ICONS.append('chevron-circle-up')
ICONS.append('chevron-circle-down')
ICONS.append('html5')
ICONS.append('css3')
ICONS.append('anchor')
ICONS.append('unlock-alt')
ICONS.append('bullseye')
ICONS.append('ellipsis-h')
ICONS.append('ellipsis-v')
ICONS.append('rss-square')
ICONS.append('play-circle')
ICONS.append('ticket')
ICONS.append('minus-square')
ICONS.append('minus-square-o')
ICONS.append('level-up')
ICONS.append('level-down')
ICONS.append('check-square')
ICONS.append('pencil-square')
ICONS.append('external-link-square')
ICONS.append('share-square')
ICONS.append('compass')
ICONS.append('toggle-down')
ICONS.append('caret-square-o-down')
ICONS.append('toggle-up')
ICONS.append('caret-square-o-up')
ICONS.append('toggle-right')
ICONS.append('caret-square-o-right')
ICONS.append('euro')
ICONS.append('eur')
ICONS.append('gbp')
ICONS.append('dollar')
ICONS.append('usd')
ICONS.append('rupee')
ICONS.append('inr')
ICONS.append('cny')
ICONS.append('rmb')
ICONS.append('yen')
ICONS.append('jpy')
ICONS.append('ruble')
ICONS.append('rouble')
ICONS.append('rub')
ICONS.append('won')
ICONS.append('krw')
ICONS.append('bitcoin')
ICONS.append('btc')
ICONS.append('file')
ICONS.append('file-text')
ICONS.append('sort-alpha-asc')
ICONS.append('sort-alpha-desc')
ICONS.append('sort-amount-asc')
ICONS.append('sort-amount-desc')
ICONS.append('sort-numeric-asc')
ICONS.append('sort-numeric-desc')
ICONS.append('thumbs-up')
ICONS.append('thumbs-down')
ICONS.append('youtube-square')
ICONS.append('youtube')
ICONS.append('xing')
ICONS.append('xing-square')
ICONS.append('youtube-play')
ICONS.append('dropbox')
ICONS.append('stack-overflow')
ICONS.append('instagram')
ICONS.append('flickr')
ICONS.append('adn')
ICONS.append('bitbucket')
ICONS.append('bitbucket-square')
ICONS.append('tumblr')
ICONS.append('tumblr-square')
ICONS.append('long-arrow-down')
ICONS.append('long-arrow-up')
ICONS.append('long-arrow-left')
ICONS.append('long-arrow-right')
ICONS.append('apple')
ICONS.append('windows')
ICONS.append('android')
ICONS.append('linux')
ICONS.append('dribbble')
ICONS.append('skype')
ICONS.append('foursquare')
ICONS.append('trello')
ICONS.append('female')
ICONS.append('male')
ICONS.append('gittip')
ICONS.append('gratipay')
ICONS.append('sun-o')
ICONS.append('moon-o')
ICONS.append('archive')
ICONS.append('bug')
ICONS.append('vk')
ICONS.append('weibo')
ICONS.append('renren')
ICONS.append('pagelines')
ICONS.append('stack-exchange')
ICONS.append('arrow-circle-o-right')
ICONS.append('arrow-circle-o-left')
ICONS.append('toggle-left')
ICONS.append('caret-square-o-left')
ICONS.append('dot-circle-o')
ICONS.append('wheelchair')
ICONS.append('vimeo-square')
ICONS.append('turkish-lira')
ICONS.append('try')
ICONS.append('plus-square-o')
ICONS.append('space-shuttle')
ICONS.append('slack')
ICONS.append('envelope-square')
ICONS.append('wordpress')
ICONS.append('openid')
ICONS.append('institution')
ICONS.append('bank')
ICONS.append('university')
ICONS.append('mortar-board')
ICONS.append('graduation-cap')
ICONS.append('yahoo')
ICONS.append('google')
ICONS.append('reddit')
ICONS.append('reddit-square')
ICONS.append('stumbleupon-circle')
ICONS.append('stumbleupon')
ICONS.append('delicious')
ICONS.append('digg')
ICONS.append('pied-piper-pp')
ICONS.append('pied-piper-alt')
ICONS.append('drupal')
ICONS.append('joomla')
ICONS.append('language')
ICONS.append('fax')
ICONS.append('building')
ICONS.append('child')
ICONS.append('paw')
ICONS.append('spoon')
ICONS.append('cube')
ICONS.append('cubes')
ICONS.append('behance')
ICONS.append('behance-square')
ICONS.append('steam')
ICONS.append('steam-square')
ICONS.append('recycle')
ICONS.append('automobile')
ICONS.append('car')
ICONS.append('cab')
ICONS.append('taxi')
ICONS.append('tree')
ICONS.append('spotify')
ICONS.append('deviantart')
ICONS.append('soundcloud')
ICONS.append('database')
ICONS.append('file-pdf-o')
ICONS.append('file-word-o')
ICONS.append('file-excel-o')
ICONS.append('file-powerpoint-o')
ICONS.append('file-photo-o')
ICONS.append('file-picture-o')
ICONS.append('file-image-o')
ICONS.append('file-zip-o')
ICONS.append('file-archive-o')
ICONS.append('file-sound-o')
ICONS.append('file-audio-o')
ICONS.append('file-movie-o')
ICONS.append('file-video-o')
ICONS.append('file-code-o')
ICONS.append('vine')
ICONS.append('codepen')
ICONS.append('jsfiddle')
ICONS.append('life-bouy')
ICONS.append('life-buoy')
ICONS.append('life-saver')
ICONS.append('support')
ICONS.append('life-ring')
ICONS.append('circle-o-notch')
ICONS.append('ra')
ICONS.append('resistance')
ICONS.append('rebel')
ICONS.append('ge')
ICONS.append('empire')
ICONS.append('git-square')
ICONS.append('git')
ICONS.append('y-combinator-square')
ICONS.append('yc-square')
ICONS.append('hacker-news')
ICONS.append('tencent-weibo')
ICONS.append('qq')
ICONS.append('wechat')
ICONS.append('weixin')
ICONS.append('send')
ICONS.append('paper-plane')
ICONS.append('send-o')
ICONS.append('paper-plane-o')
ICONS.append('history')
ICONS.append('circle-thin')
ICONS.append('header')
ICONS.append('paragraph')
ICONS.append('sliders')
ICONS.append('share-alt')
ICONS.append('share-alt-square')
ICONS.append('bomb')
ICONS.append('soccer-ball-o')
ICONS.append('futbol-o')
ICONS.append('tty')
ICONS.append('binoculars')
ICONS.append('plug')
ICONS.append('slideshare')
ICONS.append('twitch')
ICONS.append('yelp')
ICONS.append('newspaper-o')
ICONS.append('wifi')
ICONS.append('calculator')
ICONS.append('paypal')
ICONS.append('google-wallet')
ICONS.append('cc-visa')
ICONS.append('cc-mastercard')
ICONS.append('cc-discover')
ICONS.append('cc-amex')
ICONS.append('cc-paypal')
ICONS.append('cc-stripe')
ICONS.append('bell-slash')
ICONS.append('bell-slash-o')
ICONS.append('trash')
ICONS.append('copyright')
ICONS.append('at')
ICONS.append('eyedropper')
ICONS.append('paint-brush')
ICONS.append('birthday-cake')
ICONS.append('area-chart')
ICONS.append('pie-chart')
ICONS.append('line-chart')
ICONS.append('lastfm')
ICONS.append('lastfm-square')
ICONS.append('toggle-off')
ICONS.append('toggle-on')
ICONS.append('bicycle')
ICONS.append('bus')
ICONS.append('ioxhost')
ICONS.append('angellist')
ICONS.append('cc')
ICONS.append('shekel')
ICONS.append('sheqel')
ICONS.append('ils')
ICONS.append('meanpath')
ICONS.append('buysellads')
ICONS.append('connectdevelop')
ICONS.append('dashcube')
ICONS.append('forumbee')
ICONS.append('leanpub')
ICONS.append('sellsy')
ICONS.append('shirtsinbulk')
ICONS.append('simplybuilt')
ICONS.append('skyatlas')
ICONS.append('cart-plus')
ICONS.append('cart-arrow-down')
ICONS.append('diamond')
ICONS.append('ship')
ICONS.append('user-secret')
ICONS.append('motorcycle')
ICONS.append('street-view')
ICONS.append('heartbeat')
ICONS.append('venus')
ICONS.append('mars')
ICONS.append('mercury')
ICONS.append('intersex')
ICONS.append('transgender')
ICONS.append('transgender-alt')
ICONS.append('venus-double')
ICONS.append('mars-double')
ICONS.append('venus-mars')
ICONS.append('mars-stroke')
ICONS.append('mars-stroke-v')
ICONS.append('mars-stroke-h')
ICONS.append('neuter')
ICONS.append('genderless')
ICONS.append('facebook-official')
ICONS.append('pinterest-p')
ICONS.append('whatsapp')
ICONS.append('server')
ICONS.append('user-plus')
ICONS.append('user-times')
ICONS.append('hotel')
ICONS.append('bed')
ICONS.append('viacoin')
ICONS.append('train')
ICONS.append('subway')
ICONS.append('medium')
ICONS.append('yc')
ICONS.append('y-combinator')
ICONS.append('optin-monster')
ICONS.append('opencart')
ICONS.append('expeditedssl')
ICONS.append('battery-4')
ICONS.append('battery')
ICONS.append('battery-full')
ICONS.append('battery-3')
ICONS.append('battery-three-quarters')
ICONS.append('battery-2')
ICONS.append('battery-half')
ICONS.append('battery-1')
ICONS.append('battery-quarter')
ICONS.append('battery-0')
ICONS.append('battery-empty')
ICONS.append('mouse-pointer')
ICONS.append('i-cursor')
ICONS.append('object-group')
ICONS.append('object-ungroup')
ICONS.append('sticky-note')
ICONS.append('sticky-note-o')
ICONS.append('cc-jcb')
ICONS.append('cc-diners-club')
ICONS.append('clone')
ICONS.append('balance-scale')
ICONS.append('hourglass-o')
ICONS.append('hourglass-1')
ICONS.append('hourglass-start')
ICONS.append('hourglass-2')
ICONS.append('hourglass-half')
ICONS.append('hourglass-3')
ICONS.append('hourglass-end')
ICONS.append('hourglass')
ICONS.append('hand-grab-o')
ICONS.append('hand-rock-o')
ICONS.append('hand-stop-o')
ICONS.append('hand-paper-o')
ICONS.append('hand-scissors-o')
ICONS.append('hand-lizard-o')
ICONS.append('hand-spock-o')
ICONS.append('hand-pointer-o')
ICONS.append('hand-peace-o')
ICONS.append('trademark')
ICONS.append('registered')
ICONS.append('creative-commons')
ICONS.append('gg')
ICONS.append('gg-circle')
ICONS.append('tripadvisor')
ICONS.append('odnoklassniki')
ICONS.append('odnoklassniki-square')
ICONS.append('get-pocket')
ICONS.append('wikipedia-w')
ICONS.append('safari')
ICONS.append('chrome')
ICONS.append('firefox')
ICONS.append('opera')
ICONS.append('internet-explorer')
ICONS.append('tv')
ICONS.append('television')
ICONS.append('contao')
ICONS.append('500px')
ICONS.append('amazon')
ICONS.append('calendar-plus-o')
ICONS.append('calendar-minus-o')
ICONS.append('calendar-times-o')
ICONS.append('calendar-check-o')
ICONS.append('industry')
ICONS.append('map-pin')
ICONS.append('map-signs')
ICONS.append('map-o')
ICONS.append('map')
ICONS.append('commenting')
ICONS.append('commenting-o')
ICONS.append('houzz')
ICONS.append('vimeo')
ICONS.append('black-tie')
ICONS.append('fonticons')
ICONS.append('reddit-alien')
ICONS.append('edge')
ICONS.append('credit-card-alt')
ICONS.append('codiepie')
ICONS.append('modx')
ICONS.append('fort-awesome')
ICONS.append('usb')
ICONS.append('product-hunt')
ICONS.append('mixcloud')
ICONS.append('scribd')
ICONS.append('pause-circle')
ICONS.append('pause-circle-o')
ICONS.append('stop-circle')
ICONS.append('stop-circle-o')
ICONS.append('shopping-bag')
ICONS.append('shopping-basket')
ICONS.append('hashtag')
ICONS.append('bluetooth')
ICONS.append('bluetooth-b')
ICONS.append('percent')
ICONS.append('gitlab')
ICONS.append('wpbeginner')
ICONS.append('wpforms')
ICONS.append('envira')
ICONS.append('universal-access')
ICONS.append('wheelchair-alt')
ICONS.append('question-circle-o')
ICONS.append('blind')
ICONS.append('audio-description')
ICONS.append('volume-control-phone')
ICONS.append('braille')
ICONS.append('assistive-listening-systems')
ICONS.append('asl-interpreting')
ICONS.append('american-sign-language-interpreting')
ICONS.append('deafness')
ICONS.append('hard-of-hearing')
ICONS.append('deaf')
ICONS.append('glide')
ICONS.append('glide-g')
ICONS.append('signing')
ICONS.append('sign-language')
ICONS.append('low-vision')
ICONS.append('viadeo')
ICONS.append('viadeo-square')
ICONS.append('snapchat')
ICONS.append('snapchat-ghost')
ICONS.append('snapchat-square')
ICONS.append('pied-piper')
ICONS.append('first-order')
ICONS.append('yoast')
ICONS.append('themeisle')
ICONS.append('google-plus-circle')
ICONS.append('google-plus-official')
ICONS.append('fa')
ICONS.append('font-awesome')
ICONS.append('handshake-o')
ICONS.append('envelope-open')
ICONS.append('envelope-open-o')
ICONS.append('linode')
ICONS.append('address-book')
ICONS.append('address-book-o')
ICONS.append('vcard')
ICONS.append('address-card')
ICONS.append('vcard-o')
ICONS.append('address-card-o')
ICONS.append('user-circle')
ICONS.append('user-circle-o')
ICONS.append('user-o')
ICONS.append('id-badge')
ICONS.append('drivers-license')
ICONS.append('id-card')
ICONS.append('drivers-license-o')
ICONS.append('id-card-o')
ICONS.append('quora')
ICONS.append('free-code-camp')
ICONS.append('telegram')
ICONS.append('thermometer-4')
ICONS.append('thermometer')
ICONS.append('thermometer-full')
ICONS.append('thermometer-3')
ICONS.append('thermometer-three-quarters')
ICONS.append('thermometer-2')
ICONS.append('thermometer-half')
ICONS.append('thermometer-1')
ICONS.append('thermometer-quarter')
ICONS.append('thermometer-0')
ICONS.append('thermometer-empty')
ICONS.append('shower')
ICONS.append('bathtub')
ICONS.append('s15')
ICONS.append('bath')
ICONS.append('podcast')
ICONS.append('window-maximize')
ICONS.append('window-minimize')
ICONS.append('window-restore')
ICONS.append('times-rectangle')
ICONS.append('window-close')
ICONS.append('times-rectangle-o')
ICONS.append('window-close-o')
ICONS.append('bandcamp')
ICONS.append('grav')
ICONS.append('etsy')
ICONS.append('imdb')
ICONS.append('ravelry')
ICONS.append('eercast')
ICONS.append('microchip')
ICONS.append('snowflake-o')
ICONS.append('superpowers')
ICONS.append('wpexplorer')
ICONS.append('meetup')

ICON_CHOICES = [['<i class="fa fa-{} fa-fw"></i>'.format(icon_name), icon_name] for icon_name in ICONS]
