# Generated by Django 2.1.7 on 2019-03-26 22:56

from django.db import migrations
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0012_user_token'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='name',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=100, verbose_name='Nome'),
        ),
    ]
