*,:after,:before{box-sizing:border-box}a{color:#337ab7;text-decoration:none}a:focus,a:hover{color:#23527c;text-decoration:underline}body{color:#606873;position:relative;transition:padding-top .3s linear;padding-top:0;margin:0;font-family:Helvetica Neue,Helvetica,Arial,sans-serif;font-size:14px;line-height:1.42857143;background-color:#fff}h4{font-size:22px;font-weight:400}.site-header{position:relative;background-size:cover;background-repeat:no-repeat;overflow:hidden;padding:120px 0;color:#fff;z-index:0}.site-header.overlay-black:before{position:absolute;content:"";top:0;left:0;right:0;bottom:0;z-index:-1}.site-header.overlay-white.overlay-intense:before{background-color:hsla(0,0%,100%,.55)}.site-header.overlay-black:before{background-color:rgba(0,0,0,.33)}.site-header.overlay-black.overlay-intense:before{background-color:rgba(0,0,0,.55)}.site-header.bg-repeat{background-size:none;background-repeat:repeat}.site-header.bg-fixed{background-attachment:fixed}.site-header.size-full{height:100vh}.site-header.color-alt h1,.site-header.color-alt h2,.site-header.color-alt h3,.site-header.color-alt h4,.site-header.color-alt h5,.site-header.color-alt h6,.site-header.color-alt p{color:#fff}.site-header h1{font-weight:200;font-size:48px;line-height:64px;margin-bottom:24px;letter-spacing:2px}.site-header h3,.site-header h4{letter-spacing:1px;line-height:36px}.text-center{text-align:center}.container{margin-right:auto;margin-left:auto;padding-left:15px;padding-right:15px}.btn-outline.btn-white{color:#fff;border-color:#fff;box-shadow:none}.btn-round.btn-lg{border-radius:28px}.btn-outline{background-color:transparent;border-width:1px}.btn-lg{line-height:56px;padding:0 40px}.btn{line-height:42px;font-size:13px;font-weight:600;text-transform:uppercase;letter-spacing:1px;border-radius:3px;padding-left:30px;padding-top:5px;padding-bottom:5px;color:#fff;transition:all .2s ease;display:inline-block;margin-bottom:0;text-align:center;vertical-align:middle;-ms-touch-action:manipulation;touch-action:manipulation;cursor:pointer;background-image:none;border:1px solid transparent;white-space:nowrap}.btn:hover{color:#626262;text-decoration:none;background-color:#FFF}@media (max-width: 767px){.site-header{padding:60px 0}.site-header h1{font-size:28px;line-height:40px;margin-bottom:36px}.site-header h4{line-height:28px;font-size:17px}.transparent-nav .site-header{padding-top:160px}.transparent-nav .site-header.size-sm{padding-top:130px}.transparent-nav .site-header.size-lg{padding-top:190px}}