{% if component.as_pdf %}{% else %}
<div class="{% if component.left or component.right %}dashboard-wrapper{% endif %}">
{% if component.top %}
  <div class="dashboard-header">
      {% for item in component.top %}
            {{ item|safe }}
      {% endfor %}
  </div>
{% endif %}
{% if component.center %}
  <div class="dashboard-main">
      {% for item in component.center %}
            {{ item|safe }}
      {% endfor %}
  </div>
{% endif %}
{% if component.left %}
  <div class="dashboard-aside dashboard-aside-1">
      {% for item in component.left %}
            {{ item|safe }}
      {% endfor %}
  </div>
{% endif %}
{% if component.right %}
  <div class="dashboard-aside dashboard-aside-2">
      {% for item in component.right %}
            {{ item|safe }}
      {% endfor %}
  </div>
{% endif %}
{% if component.bottom %}
  <div class="dashboard-footer">
      {% for item in component.bottom %}
            {{ item|safe }}
      {% endfor %}
  </div>
{% endif %}
</div>
{% endif %}