# Generated by Django 2.0.8 on 2019-02-12 15:39

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import djangoplus.db.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0008_auto_20190212_1519'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='group',
            options={'verbose_name': 'Group', 'verbose_name_plural': 'Groups'},
        ),
        migrations.AlterModelOptions(
            name='organization',
            options={'verbose_name': 'Organization', 'verbose_name_plural': 'Organizations'},
        ),
        migrations.AlterModelOptions(
            name='permission',
            options={'verbose_name': 'Permission', 'verbose_name_plural': 'Permissions'},
        ),
        migrations.AlterModelOptions(
            name='role',
            options={'verbose_name': 'Role', 'verbose_name_plural': 'Roles'},
        ),
        migrations.AlterModelOptions(
            name='settings',
            options={'verbose_name': 'Settings', 'verbose_name_plural': 'Settings'},
        ),
        migrations.AlterModelOptions(
            name='unit',
            options={'verbose_name': 'Unit', 'verbose_name_plural': 'Units'},
        ),
        migrations.AlterModelOptions(
            name='user',
            options={'verbose_name': 'User', 'verbose_name_plural': 'Users'},
        ),
        migrations.AlterField(
            model_name='log',
            name='content',
            field=djangoplus.db.models.fields.TextField(null=True, verbose_name='Content'),
        ),
        migrations.AlterField(
            model_name='log',
            name='content_type',
            field=djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='admin.ContentType', verbose_name='Content Type'),
        ),
        migrations.AlterField(
            model_name='log',
            name='date',
            field=djangoplus.db.models.fields.DateTimeField(auto_now=True, verbose_name='Date/Time'),
        ),
        migrations.AlterField(
            model_name='log',
            name='object_description',
            field=djangoplus.db.models.fields.CharField(max_length=255, verbose_name='Object Description'),
        ),
        migrations.AlterField(
            model_name='log',
            name='object_id',
            field=djangoplus.db.models.fields.IntegerField(verbose_name='Identifier'),
        ),
        migrations.AlterField(
            model_name='log',
            name='operation',
            field=djangoplus.db.models.fields.IntegerField(choices=[[1, 'Add'], [2, 'Edit'], [3, 'Delete']], verbose_name='Operation'),
        ),
        migrations.AlterField(
            model_name='log',
            name='user',
            field=djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='logindex',
            name='content_type',
            field=djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType', verbose_name='Content Type'),
        ),
        migrations.AlterField(
            model_name='logindex',
            name='object_id',
            field=djangoplus.db.models.fields.IntegerField(verbose_name='Identifier'),
        ),
        migrations.AlterField(
            model_name='role',
            name='group',
            field=djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='admin.Group', verbose_name='Group'),
        ),
        migrations.AlterField(
            model_name='role',
            name='user',
            field=djangoplus.db.models.fields.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='address',
            field=djangoplus.db.models.fields.TextField(blank=True, null=True, verbose_name='Address'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='company',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Company Name'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='email',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Email'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='icon',
            field=djangoplus.db.models.fields.ImageField(blank=True, default='blank.png', null=True, upload_to='config', verbose_name='Icon'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='initials',
            field=djangoplus.db.models.fields.CharField(default='Django+', max_length=255, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='logo',
            field=djangoplus.db.models.fields.ImageField(blank=True, default='', null=True, upload_to='config', verbose_name='Logo'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='logo_pdf',
            field=djangoplus.db.models.fields.ImageField(blank=True, default='', help_text='No-background image', null=True, upload_to='config', verbose_name='PDF Logo'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='name',
            field=djangoplus.db.models.fields.CharField(default='Django Plus', max_length=255, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='phone_1',
            field=djangoplus.db.models.fields.PhoneField(blank=True, max_length=255, null=True, verbose_name='Primary Phome'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='phone_2',
            field=djangoplus.db.models.fields.PhoneField(blank=True, max_length=255, null=True, verbose_name='Secondary Phone'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='pinterest',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=255, null=True, verbose_name='Pinterest'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='server_address',
            field=djangoplus.db.models.fields.CharField(default='http://localhost:8000', max_length=255, verbose_name='Server URL'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='system_email_address',
            field=djangoplus.db.models.fields.CharField(default='no-reply@djangoplus.net', max_length=255, verbose_name='Notificaton E-mail'),
        ),
        migrations.AlterField(
            model_name='settings',
            name='version',
            field=djangoplus.db.models.fields.CharField(max_length=255, null=True, verbose_name='System Version'),
        ),
        migrations.AlterField(
            model_name='user',
            name='active',
            field=djangoplus.db.models.fields.BooleanField(default=True, verbose_name='Active'),
        ),
        migrations.AlterField(
            model_name='user',
            name='name',
            field=djangoplus.db.models.fields.CharField(blank=True, max_length=30, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='user',
            name='permission_mapping',
            field=djangoplus.db.models.fields.JsonField(null=True, verbose_name='Permissions Mapping'),
        ),
        migrations.AlterField(
            model_name='user',
            name='photo',
            field=djangoplus.db.models.fields.ImageField(blank=True, default='user.png', null=True, upload_to='profiles', verbose_name='Photo'),
        ),
        migrations.AlterField(
            model_name='user',
            name='username',
            field=djangoplus.db.models.fields.CharField(max_length=30, unique=True, verbose_name='Username'),
        ),
    ]
