# Generated by Django 2.0.3 on 2018-04-16 10:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('admin', '0004_auto_20180416_1037'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='organizationrole',
            name='organization',
        ),
        migrations.RemoveField(
            model_name='organizationrole',
            name='role',
        ),
        migrations.RemoveField(
            model_name='unitrole',
            name='role',
        ),
        migrations.RemoveField(
            model_name='unitrole',
            name='unit',
        ),
        migrations.DeleteModel(
            name='OrganizationRole',
        ),
        migrations.DeleteModel(
            name='UnitRole',
        ),
        migrations.DeleteModel(
            name='Role',
        ),
    ]
